/*
 * File:  RandDef.c
 * Source file of definitions of random number generating functions
 */

#include "RandDef.h"

/*
 * Function to seed the random number generator
 * Pre:	none
 * Post:	Random number generator has been seeded.
 */

void SeedRand(void)
{
	srand((unsigned) time((time_t *)NULL));
}

/*
 * Function to return a random float between 0 and 1  
 * Pre:  none
 * Post: A random floating point number between 0 and 1
 *       has been returned
 */
 
float random_float(void) 
{
	return((float) rand() / RAND_MAX);
}

/*
 * Function to generate a random floating point number 
 * between LowerBound  and UpperBound - 1
 * Pre:	LowerBound and UpperBound are of type float.
 * Post:	A random integer between LowerBound and  
 *        UpperBound - 1 has been returned.
 */

float random_float_range(float LowerBound, float UpperBound)
{
	float random_0_1;	/* random number between 0 and 1 */
	
	random_0_1 = (float)rand() / RAND_MAX;
	return ((UpperBound - LowerBound) *  random_0_1 
					+ LowerBound);
}

/*
 * Function to generate a random integer 
 * between 0 and upper_bound - 1
 * Pre:	upper_bound <> 0
 * Post:	Random integer returned.
 */

int random(int UpperBound)
{
	float random_0_1;	/* random number between 0 and 1 */

	random_0_1 = (float) rand() / RAND_MAX;
	return ((int)(UpperBound * random_0_1 ));
}

/*
 * Function to generate a random integer 
 * between LowerBound  and UpperBound - 1
 * Pre:	LowerBound and UpperBound are integers.
 * Post:	A random integer between LowerBound and  
 *        UpperBound - 1 has been returned.
 */

int random_range(int LowerBound, int UpperBound)
{
	float random_0_1;	/* random number between 0 and 1 */

	random_0_1 = (float) rand() / RAND_MAX;
	return ((int)((UpperBound - LowerBound) *  random_0_1)
			+ LowerBound);
}
